@@ -102,6 +102,7 @@ defaultConfig = dict(
     PlugIns=['MiscUtils', 'WebUtils', 'TaskKit', 'UserKit', 'PSP'],
     PrintConfigAtStartUp=True,
     PrintPlugIns=True,
+    RegisterSignalHandler=False,
     ReloadServletClasses=False,
     ReportRPCExceptionsInWebware=True,
     ResponseBufferSize=8 * 1024,  # 8 kBytes
@@ -111,6 +112,8 @@ defaultConfig = dict(
     SaveErrorMessages=True,
     SecureSessionCookie=True,
     SessionCookiePath=None,
+    HttpOnlySessionCookie=True,
+    SameSiteSessionCookie='Strict',
     SessionModule='Session',
     SessionName='_SID_',
     SessionPrefix='',
@@ -250,11 +253,12 @@ class Application(ConfigurableForServerSidePath):
 
         self._needsShutDown = [True]
         atexit.register(self.shutDown)
-        self._sigTerm = signal.signal(signal.SIGTERM, self.sigTerm)
-        try:
-            self._sigHup = signal.signal(signal.SIGHUP, self.sigTerm)
-        except AttributeError:
-            pass  # SIGHUP does not exist on Windows
+        if self.setting('RegisterSignalHandler'):
+            self._sigTerm = signal.signal(signal.SIGTERM, self.sigTerm)
+            try:
+                self._sigHup = signal.signal(signal.SIGHUP, self.sigTerm)
+            except AttributeError:
+                pass  # SIGHUP does not exist on Windows
 
     def initErrorPage(self):
         """Initialize the error page related attributes."""
